@@ -860,3 +860,38 @@ def test_IVData_10_mandatory_if(datadir):
         },
     }
     assert ret == expected_errors
+
+
+def test_IVData_11_empty_tab(datadir):
+    indir, outdir = datadir
+    data = IVData()
+    data.read_excel(os.path.join(indir, "test_11.xlsx"))
+    data.read_schema(os.path.join(indir, "test_11.schema.yaml"))
+    for tab in ("names", "cars", "empty"):
+        print('checking "%s"' % tab, end="... ")
+        df, is_ok, errors = data._validate_tab(tab)
+        assert is_ok is True
+        assert errors == {}
+    # ------------------------------------------------------------------------
+    # export and reimport to/from various formats
+    for extension in (".xlsx", ".ini"):
+        target = os.path.join(outdir, "test_00" + extension)
+        print("test '%s' extension" % target)
+        assert not os.path.isfile(target)
+        data.to(target)
+        assert os.path.isfile(target)
+        # --------------------------------------------------------------------
+        # read the newly created file
+        data_new = IVData()
+        data_new.read(target)
+        data_new.read_schema(os.path.join(indir, "test_11.schema.yaml"))
+        for tab in data._data.keys():
+            print('checking "%s"' % tab, end="... ")
+            df, is_ok, errors = data_new._validate_tab(tab)
+            try:
+                assert is_ok is True
+            except:
+                print("OUPS!")
+            else:
+                print("OK")
+            assert errors == {}
